@@ -4,12 +4,16 @@ use 5.008005;
 use strict;
 use warnings;
 
-use Padre::Plugin;
+use Padre::Plugin ();
 use Padre::Unload ();
+use File::Which   ();
 
-our $VERSION = '1.22';
+our $VERSION = '1.23';
 our @ISA     = 'Padre::Plugin';
-
+# use Data::Printer {
+	# caller_info => 1,
+	# colored     => 1,
+# };
 
 #######
 # Define Plugin Name Spell Checker
@@ -25,14 +29,13 @@ sub padre_interfaces {
 	return (
 		'Padre::Plugin' => '0.94',
 		'Padre::Unload' => '0.94',
-		'Padre::Locale' => '0.94',
 
 		# used by my sub packages
+		'Padre::Locale'         => '0.94',
 		'Padre::Logger'         => '0.94',
 		'Padre::Wx'             => '0.94',
 		'Padre::Wx::Role::Main' => '0.94',
 		'Padre::Util'           => '0.94',
-
 	);
 }
 
@@ -61,18 +64,85 @@ sub menu_plugins {
 # as we have an external dependency
 #########
 sub plugin_enable {
-
+	my $self                       = shift;
 	my $local_dictonary_bin_exists = 0;
 
-	# Tests for external file in Path...
-	if ( File::Which::which('aspell') ) {
-		$local_dictonary_bin_exists = 1;
-	} elsif ( File::Which::which('hunspell') ) {
+	# Tests for externals used by Preference's
+	if ( eval { require Text::Aspell } ) {
 		$local_dictonary_bin_exists = 1;
 	}
+	if ( File::Which::which('hunspell') ) {
+		$local_dictonary_bin_exists = 1;
+	}
+
+	#Set/ReSet Config data
+	$self->_config if $local_dictonary_bin_exists;
+
+	# p $self->_config_read;
+
 	return $local_dictonary_bin_exists;
 }
 
+#######
+# Composed Method _config
+# called on enable in plugin manager, bit like run/setup for a Plugin
+#######
+sub _config {
+	my $self   = shift;
+	my $config = $self->config_read;
+
+	###
+	#	Info P-P-SpellCheck 	< 1.21
+	#	$config->{dictionary}   = iso
+	#
+	#	Info P-P-SpellCheck     = 1.22
+	#	- $config->{dictionary} = iso
+	#	+ $config->{Aspell}     = en_GB
+	#	+ $config->{Hunspell}   = en_AU
+	#	+ $config->{Version}    = $VERSION
+	#
+	#	Info P-P-SpellCheck    >= 1.23
+	#	+ $config->{Engine}     = 'Aspell'
+	###
+	if ( eval { $config->{Version} >= 1.23; } ) {
+		return;
+	} elsif (
+		eval {
+			$config->{Version} < 1.23;
+		}
+		)
+	{
+		$config->{Version} = $VERSION;
+		$config->{Engine}  = 'Aspell';
+		$self->config_write($config);
+		return;
+	} elsif (
+		eval {
+			$config->{dictionary};
+		}
+		)
+	{
+		my $tmp_iso = $config->{dictionary};
+		$self->config_write( {} );
+		$config             = $self->config_read;
+		$config->{Aspell}   = $tmp_iso;
+		$config->{Hunspell} = $tmp_iso;
+		$config->{Version}  = $VERSION;
+		$config->{Engine}   = 'Aspell';
+		$self->config_write($config);
+		return;
+	} else {
+		$self->config_write( {} );
+		$config->{Aspell}   = 'en_GB';
+		$config->{Hunspell} = 'en_GB';
+		$config->{Version}  = $VERSION;
+		$config->{Engine}   = 'Aspell';
+		$self->config_write($config);
+	}
+
+	return;
+}
+
 ########
 # plugin_disable
 ########
@@ -151,6 +221,7 @@ sub spell_check {
 	return;
 }
 
+
 1;
 
 __END__
@@ -169,6 +240,13 @@ sub plugin_icon {
 		return Wx::Bitmap->new( $iconpath, Wx::wxBITMAP_TYPE_PNG );
 }
 
+sub menu_plugins_simple {
+	my $self = shift;
+	return Wx::gettext('Spell Check') => [
+		Wx::gettext("Check spelling...\tF7") => sub { $self->spell_check },
+		Wx::gettext('Preferences')           => sub { $self->plugin_preferences },
+	];
+}
 
 
 =head1 NAME
@@ -177,63 +255,64 @@ Padre::Plugin::SpellCheck - Check spelling in Padre The Perl IDE
 
 =head1 DESCRIPTION
 
-This plugins allows one to check there text spelling within Padre using
-C<F7> (standard spelling shortcut across text processors). 
+This plug-in allows one to check there spelling within Padre using
+C<F7> (standard spelling short-cut across text processors). 
 
 One can change the dictionary language used (based upon install languages) in the preferences window via Plug-in Manager. 
 Preferences are persistent. You need to Save your preferred language.
 
-This plugin is using C<Text::Aspell> default at present, You can also use C<Text::Hunspell> under-development, so check these module's
-pod for more information.
+This plug-in is using C<Text::Aspell> default (legacy). You can also use C<Text::Hunspell>, so check these module's
+pod for more information and install the one for you.
 
 Of course, you need to have the relevant Dictionary binary, dev and dictionary installed.
 
 
 =head1 SYNOPSIS
 
-    $ padre file-with-spell-errors
+    Check your file or selected text for spelling errors in your preferred language.
     F7
 
-
 =head1 PUBLIC METHODS
 
 =head2 Standard Padre::Plugin API
 
-C<Padre::Plugin::SpellCheck> defines a plugin which follows
+C<Padre::Plugin::SpellCheck> defines a plug-in which follows
 C<Padre::Plugin> API. Refer to this module's documentation for more
 information.
 
 The following methods are implemented:
 
-=over 4
+=over 7
 
-=item menu_plugins_simple()
+=item clean_dialog()
+
+=item menu_plugins()
 
 =item padre_interfaces()
 
-=item plugin_icon()
+=item plugin_disable()
+
+=item plugin_enable()
+
+Return the plug-in's configuration, or a suitable default one if none exist previously.
 
 =item plugin_name()
 
+=item plugin_preferences()
+
+Open the check spelling preferences window.
+
 =back
 
 
 =head2 Spell checking methods
 
-=over 4
-
-=item * config()
-
-Return the plugin's configuration, or a suitable default one if none
-exist previously.
+=over 1
 
 =item * spell_check()
 
 Spell checks the current selection (or the whole document).
 
-=item * plugin_preferences()
-
-Open the check spelling preferences window.
 
 =back
 
@@ -242,8 +321,8 @@ Open the check spelling preferences window.
 Spell-checking non-ascii files has bugs: the selection does not
 match the word boundaries, and as the spell checks moves further in
 the document, offsets are totally irrelevant. This is a bug in
-C<Wx::StyledTextCtrl> that has some unicode problems... So
-unfortunately, there's nothing that I can do in this plugin to
+C<Wx::StyledTextCtrl> that has some Unicode problems... So
+unfortunately, there's nothing that I can do in this plug-in to
 tackle this bug.
 
 Please report any bugs or feature requests to C<padre-plugin-spellcheck
@@ -256,13 +335,22 @@ notified of progress on your bug as I make changes.
 
 =head1 SEE ALSO
 
-Plugin icon courtesy of Mark James, at
+Plug-in icon courtesy of Mark James, at
 L<http://www.famfamfam.com/lab/icons/silk/>.
 
-Our svn repository is located at L<http://svn.perlide.org/padre/trunk/Padre-Plugin-
-SpellCheck>, and can be browsed at L<http://padre.perlide.org/browser/trunk/Padre-Plugin-
-SpellCheck>.
+=over 2
 
+=item * Padre-Plugin-SpellCheck web page
+
+L<http://padre.perlide.org/trac/wiki/PadrePluginSpellCheck>
+
+=item * Our svn repository 
+
+L<http://svn.perlide.org/padre/trunk/Padre-Plugin-SpellCheck>, 
+and can be browsed at 
+L<http://padre.perlide.org/browser/trunk/Padre-Plugin-SpellCheck>.
+
+=back
 
 You can also look for information on this module at:
 
@@ -282,7 +370,9 @@ L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Padre-Plugin-SpellCheck>
 
 =back
 
-Everything aspell related: L<http://aspell.net>.
+Everything Aspell related: L<http://aspell.net>.
+
+Everything Hunspell related: L<http://hunspell.sourceforge.net/>.
 
 =head1 AUTHORS
 
